antares.apps.message package
============================

Subpackages
-----------

.. toctree::

   antares.apps.message.api
   antares.apps.message.migrations
   antares.apps.message.models
   antares.apps.message.serializers
   antares.apps.message.service
   antares.apps.message.tests

Submodules
----------

antares.apps.message.admin module
---------------------------------

.. automodule:: antares.apps.message.admin
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.message.apps module
--------------------------------

.. automodule:: antares.apps.message.apps
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.message.constants module
-------------------------------------

.. automodule:: antares.apps.message.constants
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.message.urls module
--------------------------------

.. automodule:: antares.apps.message.urls
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.message
   :members:
   :undoc-members:
   :show-inheritance:
